% comp_wcorr() - Calculating the correlation coeffieicnts between components listed in the selected
%                component list per the entire or selected portion of time courses. 
%
% Input:
%   z_thre    - z threshold to select significant voxels
%   comp_list - component list, 0 (default) = use FMRI.icacomp; 1 = all components available
%   tp        - time points of the time course used to yield the correlation measure
%               0 (default) = the entire time course; [a:b] = time points from a to b
%
% Output:
%   wcc - array containing correlateion coeffieicnets between component weights

function [wcc,tc] = comp_wcorr(z_thre,comp_list,tp)

if nargin < 3,
    tp = 0;
end
if nargin < 2,
    comp_list = 0;
end
if nargin < 1,
    z_thre = 2.0
end

global FMRI

if isempty(findstr(FMRI.processed,'ica_trained')),
    fmrlab_messagedlg('comp_wcorr()',...
        'Error:',...
        'No ICA results available, please run ''Process >> Run ICA''');
end

if comp_list == 0,
    comps = FMRI.icacomp;
else
    if FMRI.pcano ~= 0,
        comps = 1:FMRI.pcano;
    else
        comps = 1:size(FMRI.icaweight,1);
    end
end

W = FMRI.icaweight * FMRI.icasphere;
u = W * FMRI.data;
invW = pinv(W);
if tp == 0,
    tp = 1:size(invW,1);
end

tc = zeros(length(tp),length(comps));
for ii = 1:length(comps),
    % finding significant voxels
    temp = u(comps(ii),:);
    temp = (temp-mean(temp))/std(temp);
    pii = find(temp>=z_thre);
    nii = find(temp<=-z_thre);
    % back-projected component time courses
    data2 = invW(:,comps(ii)) * u(comps(ii),:);
    bptc = mean(data2(:,pii)');
    raw_mean = mean(mean(FMRI.data(:,pii)'));
    bptc = 100*(bptc-mean(bptc))/raw_mean;
    tc(:,ii) = bptc(tp)';
end
wcc = corrcoef(tc);