% extract_brain_ui2() - extract brain area (or remove the off-brain
%                      voxels) from the sequential fMRI data. 
%
% Usage:
%    >> extract_brain_ui2;
%
% Inputs:
%
% Outputs:
%
% Author: Jeng-Ren Duann, CNL/Salk Inst. & SCCN/INC/UCSD, 2001-10
%
% See also: extract_brain_by_edit()
%
% Notes: - This function provides users to remove the off-brain
%          voxels interactively by either:
%        - setting threshold using horizontal scroll bar, or
%        - setting threshold by keying in number in edit box
%        - before doing thresholding, press refresh first to load
%          up the images
%        - press OK to accept the thresold value
%        - press CANCEL to omit the thresholding

% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: extract_brain_ui2.m,v $
% Revision 1.3  2003/03/01 19:47:56  duann
% correct typo
%
% Revision 1.2  2003/03/01 19:38:51  duann
% reshape FMRI.data back if 'cancel' pressed
%
% Revision 1.1  2003/02/06 18:58:48  duann
% Initial revision
%

function extract_brain_ui2(action)
  
if nargin < 1,
    action = 'init';
end
 
global FMRI
global h0
global ax
global mean_data
global ii
global FS
global sf
  
if length(FMRI) == 0,
    fmrlab_messagedlg('Extract Brain Voxels',...
        'Error:',...
        ['No current data set exists. Please load a ''.fmr''' ...
            ' data files first']);
    return;
end

if size(FMRI.data,1)==FMRI.timepoint,
    fmrlab_messagedlg('Extract Brain Voxels',...
        'Error:',...
        ['Off-brain voxels have been removed. Please move' ...
            ' on to run ICA directly.']);
    return;
end
 
RGB_mainwin = [1 .984 .895];
RGB_background = [0.860 0.824 0.618];
RGB_button = [0.860 0.824 0.618];
RGB_text = [0.333 0.283 0.003];

axw = 168*sf(1);
axg = 10*min(sf);
axgh = 25*sf(2);
bw=90*sf(1);
  
if strcmp(action,'init'),
    FMRI.data = reshape(FMRI.data,FMRI.dime_x*FMRI.dime_y* ...
        FMRI.dime_z,FMRI.timepoint);
    mean_data = mean(FMRI.data');
    mean_data = reshape(mean_data,FMRI.dime_x,FMRI.dime_y, ...
        FMRI.dime_z);
    pos_w = 900*sf(1);
    pos_h = 625*sf(2);
    S = get(0,'screensize');
    pos = [(S(3)-pos_w)/2 (S(4)-pos_h)/2 pos_w pos_h];
    h0 = figure(...
        'Color',RGB_background, ...
        'PaperUnits','points', ...
        'units','pixels',...
        'Position',pos, ...
        'Tag','extract_brain_win', ...
        'name', 'Remove Off-Brain Voxels',...
        'numbertitle','off',...
        'ToolBar','none',...
        'menubar','none');
  
    ax = []; % keep the handles of image axes for further use
    for i=1:3,
        for j=1:5,
            pos(1) = j*axg + (j-1)*axw;
            pos(2) = pos_h - i*(axgh+axw);
            pos(3) = axw;
            pos(4) = axw;
            h1 = axes(...
                'Parent',h0, ...
                'units','pixels',...
                'position',pos,...
                'Color',RGB_mainwin, ...
                'box','on',...
                'Tag','image_ax',...
                'xtick',[],...
                'xticklabel',[],...
                'ytick',[],...
                'yticklabel',[]);
            ax = [ax h1];
        end
    end
    pos = [axg pos_h-1*axgh 3*bw axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'fontsize',FS,...
        'horizontalalign','left',...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string','Original data');
    pos = [axg pos_h-2*axgh-axw 3*bw axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'fontsize',FS,...
        'horizontalalign','left',...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string','Thresholded data');
    pos = [axg pos_h-3*axgh-2*axw 3*bw axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'fontsize',FS,...
        'horizontalalign','left',...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string','Thresholded data in log scale');
    
    % create slider bar
    pos = [pos_w-7.75*bw-5*axg axg .25*bw axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string','0');
    ti = sprintf('%5.0f',max(FMRI.data(:)));
    pos = [pos_w-3.5*bw-4*axg axg .5*bw axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string',ti);
    pos = [axg axg 1.5*bw 1.3*axgh];
    uicontrol(...
        'parent',h0,...
        'units','pixels',...
        'style','text',...
        'position',pos,...
        'fontsize',FS,...
        'backgroundcolor',RGB_background,...
        'foregroundcolor',RGB_text,...
        'string','Move slider or enter off-brain threshold');
    if FMRI.dime_z > 4,
        ti = sprintf('Showing middle five slices');
        pos = [pos_w-3*bw-axg pos_h-axgh 3*bw axgh];
        uicontrol(...
            'parent',h0,...
            'units','pixels',...
            'style','text',...
            'position',pos,...
            'fontsize',FS,...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string',ti);  
    end    
    pos = [pos_w-7.5*bw-4*axg axg 4*bw axgh];
    sb = uicontrol(...
        'Parent',h0, ...
        'Units','pixels', ...
        'BackgroundColor',RGB_button, ...
        'Callback','extract_brain_ui2(''refresh_slider'')', ...
        'ListboxTop',0, ...
        'Position',pos, ...
        'SliderStep',[0.001 0.01], ...
        'Style','slider', ...
        'Tag','slider1',...
        'min',0,...
        'max',round(max(FMRI.data(:))));
    pos = [pos_w-3*axg-3*bw axg bw axgh];
    ed1 = uicontrol(...
        'Parent',h0, ...
        'Units','pixels', ...
        'BackgroundColor',RGB_mainwin, ...
        'FontSize',FS, ...
        'ForegroundColor',RGB_text, ...
        'Position',pos, ...
        'Style','edit', ...
        'string','0',...
        'callback','extract_brain_ui2(''refresh_edit'')',...
        'Tag','edit1');
    pos = [pos_w-2*axg-2*bw axg bw axgh];
    bt1 = uicontrol(...
        'Parent',h0, ...
        'Units','pixels', ...
        'BackgroundColor',RGB_button, ...
        'FontSize',FS, ...
        'ForegroundColor',RGB_text, ...
        'Position',pos, ...
        'String','OK', ...
        'callback','extract_brain_ui2(''OK'')',...
        'Tag','Pushbutton1');
    pos = [pos_w-axg-bw axg bw axgh];
    bt2 = uicontrol(...
        'Parent',h0, ...
        'Units','pixels', ...
        'BackgroundColor',RGB_button, ...
        'FontSize',FS, ...
        'ForegroundColor',RGB_text, ...
        'Position',pos, ...
        'String','Cancel', ...
        'callback','extract_brain_ui2(''cancel'')',...
        'Tag','Pushbutton2');
    
    % display images
    if FMRI.dime_z < 6
      for i=1:FMRI.dime_z,
	axes(ax(i));
	imagesc(mean_data(:,:,i)');
	axis image
	axis off
	axes(ax(i+5));
	imagesc(mean_data(:,:,i)');
	axis image
	axis off
	axes(ax(i+10));
	temp = mean_data(:,:,i);
	temp = log(1+temp);
	imagesc(temp');
	axis image
	axis off
	colormap(gray);
      end
    else
      start_slice = round(FMRI.dime_z/2)-2;
      for i=start_slice+1:start_slice+5,
	axes(ax(i-start_slice));
	imagesc(mean_data(:,:,i)');
	axis image
	axis off
	axes(ax(i-start_slice+5));
	imagesc(mean_data(:,:,i)');
	axis image
	axis off
	axes(ax(i-start_slice+10));
	temp = mean_data(:,:,i);
	temp = log(1+temp);
	imagesc(temp');
	axis image
	axis off
	colormap(gray);
      end
    end
    
  elseif strcmp(action,'cancel'),
    FMRI.data = reshape(FMRI.data,FMRI.dime_x*FMRI.dime_y*...
			FMRI.dime_z*FMRI.timepoint,1);
    close(h0);
    
  elseif strcmp(action,'refresh_edit'),
    % get threshold from edit box
    a = findobj('tag','edit1');
    b =str2num(get(a,'string'));
    % set the value of slider bar
    a = findobj('tag','slider1');
    set(a,'value',b);
    temp = mean_data;
    ii = find(temp < b);
    temp(ii) = 0;
    if FMRI.dime_z < 6
      for i=1:FMRI.dime_z,
	axes(ax(i+5));
	imagesc(temp(:,:,i)');
	axis image
	axis off
	axes(ax(i+10));
	imagesc(log(1+temp(:,:,i))');
	axis image
	axis off
	colormap(gray);
      end
    else
      start_slice = round(FMRI.dime_z/2)-2;
      for i=start_slice+1:start_slice+5,
	axes(ax(i-start_slice+5));
	imagesc(temp(:,:,i)');
	axis image
	axis off
	axes(ax(i-start_slice+10));
	imagesc(log(1+temp(:,:,i))');
	axis image
	axis off
	colormap(gray);
      end
    end
        
  elseif strcmp(action,'refresh_slider'),
    % get threshold from slider
    a = findobj('tag','slider1');
    b = round(get(a,'value'));
    % set the value of slider bar
    a = findobj('tag','edit1');
    set(a,'string',num2str(b));
    temp = mean_data;
    ii = find(temp < b);
    temp(ii) = 0;
    if FMRI.dime_z < 6
      for i=1:FMRI.dime_z,
	axes(ax(i+5));
	imagesc(temp(:,:,i)');
	axis image
	axis off
	axes(ax(i+10));
	imagesc(log(1+temp(:,:,i))');
	axis image
	axis off
	colormap(gray);
      end
    else
      start_slice = round(FMRI.dime_z/2)-2;
      for i=start_slice+1:start_slice+5,
	axes(ax(i-start_slice+5));
	imagesc(temp(:,:,i)');
	axis image
	axis off
	axes(ax(i-start_slice+10));
	imagesc(log(1+temp(:,:,i))');
	axis image
	axis off
	colormap(gray);
      end
    end
    
  elseif strcmp(action, 'OK'),
    FMRI.data = FMRI.data';
    FMRI.data(:,ii) = [];
    FMRI.idx = 1:FMRI.dime_x*FMRI.dime_y*FMRI.dime_z;
    FMRI.idx(ii) = [];
    FMRI.processed = [FMRI.processed ':brain_extracted'];
    close(h0);
    show_parameters
    
  end
  
